@@ -3,6 +3,7 @@ import pandas as pd
 from .cohort_member import CohortMember
 from .base import Base #pylint: disable=[relative-beyond-top-level]
 from .student import Student
+from .user import User
 from .utils import Utils #pylint: disable=[relative-beyond-top-level]
 
 
@@ -50,12 +51,42 @@ class Cohort(Base):
         for student in students:
             self.enroll_single_student(student, status)
 
-    def get_student_list(self, output='DataFrame'):
+    def enroll_single_staff(self, staff, status='PARTICIPANT'):
+        '''
+        Add a new staff information to database
+        Parameter:
+            staff: User object include data of staffs to be added
+            status: status of the current staff in cohort (default 'PARTICIPANT')
+        '''
+        if type(staff) is not User:
+            print('ERROR: Data must be instance of User')
+            return
+        if not getattr(self, '_id', ''):
+            print('ERROR: Cohort undefined')
+            return
+        if not getattr(staff, '_id', ''):
+            print('ERROR: User undefined')
+            return
+        data = {'cohortId': self._id, 'memberType':'User', 'memberId':staff._id,
+                'status': status}
+        CohortMember.create(data)
+
+    def enroll_staffs(self, staffs, status='PARTICIPANT'):
+        '''
+        Add multiple staffs information to database
+        Parameter:
+            staffs: Multiple User object in a iterable type, include data of staffs to
+            be added
+            status: status of the current staffs in cohort (default 'PARTICIPANT')
+        '''
+        for user in staffs:
+            self.enroll_single_staff(user, status)
+
+    def get_student_list(self):
         '''
         Get student information in the current cohort from database
-        Parameter:
-            output: kind of multi-value class to holder the result. the default is 'DataFrame'
-        Return: result in corresponding output type, each single item is in Student object type
+
+        Return: a pandas DataFrame of students including cohort member, cohort group
         '''
         if not getattr(self, '_id', ''):
             print('ERROR: Cohort undefined')
@@ -71,9 +102,8 @@ class Cohort(Base):
     def get_staff_list(self):
         '''
         Get staff information in the current cohort from database
-        Parameter:
-            output: kind of multi-value class to holder the result. the default is 'DataFrame'
-        Return: result in corresponding output type, each single item is in User object type
+
+        Return: a pandas DataFrame of instructors and TAs who teach the cohort
         '''
         if not getattr(self, '_id', ''):
             print('ERROR: Cohort undefined')
